@@ -17,6 +17,9 @@
 # with this program; if not, write to the Free Software Foundation, Inc.,
 # 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
+
+from __future__ import print_function
+
 import gettext
 import locale
 import logging
@@ -26,13 +29,14 @@ from optparse import OptionParser
 
 
 # i18n
+from lazygal import py2compat
 from lazygal import INSTALL_MODE, INSTALL_PREFIX
 if INSTALL_MODE == 'source':
     LOCALES_PATH = os.path.normpath(os.path.join(os.path.dirname(__file__),
                                                  'build', 'mo'))
 elif INSTALL_MODE == 'installed':
     LOCALES_PATH = os.path.join(INSTALL_PREFIX, 'share', 'locale')
-gettext.install('lazygal', LOCALES_PATH, unicode=1)
+gettext.install('lazygal', LOCALES_PATH)
 
 locale.setlocale(locale.LC_ALL, '')
 
@@ -140,7 +144,7 @@ parser.add_option("", "--webalbum-pic-bg",
                   help=_("Webalbum picture background color. Default is transparent, and implies the PNG format. Any other value, e.g. red, white, blue, uses JPEG."))
 parser.add_option("", "--webalbum-pic-type",
                   action="store", type="choice",
-                  choices=lazygal.eyecandy.WEBALBUMPIC_TYPES.keys(),
+                  choices=list(lazygal.eyecandy.WEBALBUMPIC_TYPES.keys()),
                   dest="webalbumpic_type",
                   help=_("Webalbum picture type. Default is messy."))
 parser.add_option("", "--pic-sort-by",
@@ -159,16 +163,16 @@ parser.add_option("", "--keep-gps-data",
 (options, args) = parser.parse_args()
 
 if options.show_version:
-    print _('lazygal version %s') % lazygal.__version__
+    print(_('lazygal version %s') % lazygal.__version__)
     sys.exit(0)
 
 if len(args) != 1:
     parser.print_help()
-    sys.exit(_("Bad command line."))
+    sys.exit(_("Bad command line: wrong number of arguments."))
 
-source_dir = args[0].decode(sys.getfilesystemencoding())
+source_dir = py2compat.u(args[0], sys.getfilesystemencoding())
 if not os.path.isdir(source_dir):
-    print _("Directory %s does not exist.") % source_dir
+    print(_("Directory %s does not exist.") % source_dir)
     sys.exit(1)
 
 
@@ -184,7 +188,8 @@ if options.check_all_dirs:
 
 if options.dest_dir is not None:
     cmdline_config.set('global', 'output-directory',
-                       options.dest_dir.decode(sys.getfilesystemencoding()))
+                       py2compat.u(options.dest_dir,
+                                   sys.getfilesystemencoding()))
 if options.force_gen_pages:
     cmdline_config.set('global', 'force-gen-pages', 'Yes')
 if options.clean_destination:
@@ -223,7 +228,7 @@ if options.orig_symlink:
     try:
         os.symlink
     except AttributeError:
-        print _("Option --orig-symlink is not available on this platform.")
+        print(_("Option --orig-symlink is not available on this platform."))
         sys.exit(1)
     else:
         cmdline_config.set('webgal', 'original-symlink', 'Yes')
@@ -240,7 +245,7 @@ if options.tpl_vars is not None:
     for single_def in tpl_vars_defs:
         name, value = single_def.split('=')
         cmdline_config.set('template-vars',
-                           name, value.decode(sys.stdin.encoding))
+                           name, py2compat.u(value, sys.stdin.encoding))
 
 logger = logging.getLogger()
 logger.setLevel(logging.INFO)
@@ -250,8 +255,8 @@ logger.addHandler(output_log)
 
 try:
     album = Album(source_dir, cmdline_config)
-except ValueError, e:
-    print unicode(e)
+except ValueError as e:
+    print(py2compat.u(e))
     sys.exit(1)
 else:
     if sys.stdout.isatty():
@@ -259,7 +264,7 @@ else:
             len(album.stats()['bydir'].keys()), album.stats()['total'])
 
         def update_progress():
-            output_log.update_progress(unicode(progress))
+            output_log.update_progress(py2compat._str(progress))
         progress.updated = update_progress
         progress.updated()
     else:
@@ -272,10 +277,10 @@ else:
     try:
         album.generate(progress=progress)
     except KeyboardInterrupt:
-        print >> sys.stderr, _("Interrupted.")
+        print(_("Interrupted."), file=sys.stderr)
         sys.exit(1)
-    except ValueError, e:
-        print unicode(e)
+    except ValueError as e:
+        print(py2compat.u(e))
         sys.exit(1)
 
 
