@@ -24,20 +24,22 @@ import sys
 import re
 import shutil
 
-from config import LazygalConfig, LazygalWebgalConfig
-from config import USER_CONFIG_PATH, LazygalConfigDeprecated
-from sourcetree import SOURCEDIR_CONFIGFILE
-from pygexiv2 import GExiv2
+from .config import LazygalConfig, LazygalWebgalConfig
+from .config import USER_CONFIG_PATH, LazygalConfigDeprecated
+from .sourcetree import SOURCEDIR_CONFIGFILE
+from .pygexiv2 import GExiv2
 
-import make
-import pathutils
-import sourcetree
-import tpl
-import newsize
-import metadata
-import genpage
-import genmedia
-import genfile
+from . import py2compat
+from . import make
+from . import pathutils
+from . import sourcetree
+from . import tpl
+from . import newsize
+from . import metadata
+from . import genpage
+from . import genmedia
+from . import genfile
+from . import mediautils
 
 
 from lazygal import INSTALL_MODE, INSTALL_PREFIX
@@ -46,7 +48,7 @@ if INSTALL_MODE == 'source':
 elif INSTALL_MODE == 'installed':
     DATAPATH = os.path.join(INSTALL_PREFIX, 'share', 'lazygal')
     if not os.path.exists(os.path.join(DATAPATH, 'themes')):
-        print _('Could not find themes dir, check your installation!')
+        print(_('Could not find themes dir, check your installation!'))
         sys.exit(1)
 
 
@@ -67,31 +69,28 @@ class SubgalSort(make.MakeTask):
         logging.info(_("  SORTING pics and subdirs"))
 
         if self.webgal_dir.subgal_sort_by[0] == 'exif':
-            subgal_sorter = \
-                lambda x, y: x.source_dir.compare_latest_exif(y.source_dir)
+            subgal_sortkey = lambda x: x.source_dir.latest_media_stamp()
         elif self.webgal_dir.subgal_sort_by[0] == 'mtime':
-            subgal_sorter = \
-                lambda x, y: x.source_dir.compare_mtime(y.source_dir)
+            subgal_sortkey = lambda x: x.source_dir.get_mtime()
         elif self.webgal_dir.subgal_sort_by[0] == 'dirname'\
                 or self.webgal_dir.subgal_sort_by[0] == 'filename':  # Backward compatibility
-            subgal_sorter = \
-                lambda x, y: x.source_dir.compare_filename(y.source_dir)
+            subgal_sortkey = lambda x: x.source_dir.filename
         else:
             raise ValueError(_("Unknown sorting criterion '%s'")
                              % self.webgal_dir.subgal_sort_by[0])
-        self.webgal_dir.subgals.sort(subgal_sorter,
+        self.webgal_dir.subgals.sort(key=subgal_sortkey,
                                      reverse=self.webgal_dir.subgal_sort_by[1])
 
         if self.webgal_dir.pic_sort_by[0] == 'exif':
-            sorter = lambda x, y: x.media.compare_to_sort(y.media)
+            sortkey = lambda x: x.media.sortkey()
         elif self.webgal_dir.pic_sort_by[0] == 'mtime':
-            sorter = lambda x, y: x.media.compare_mtime(y.media)
+            sortkey = lambda x: x.media.get_mtime()
         elif self.webgal_dir.pic_sort_by[0] == 'filename':
-            sorter = lambda x, y: x.media.compare_filename(y.media)
+            sortkey = lambda x: x.media.filename
         else:
             raise ValueError(_("Unknown sorting criterion '%s'")
                              % self.webgal_dir.pic_sort_by[0])
-        self.webgal_dir.medias.sort(sorter,
+        self.webgal_dir.medias.sort(key=sortkey,
                                     reverse=self.webgal_dir.pic_sort_by[1])
 
         # chain medias
@@ -152,18 +151,16 @@ class SubgalBreak(make.MakeTask):
         galleries = []
         how_many_medias = 0
         subgals_it = iter([self.webgal_dir] + self.webgal_dir.get_all_subgals())
-        try:
-            while True:
-                subgal = subgals_it.next()
-                how_many_medias += subgal.get_media_count()
-                galleries.append((subgal, subgal.medias))
-                if how_many_medias > self.webgal_dir.thumbs_per_page:
-                    self.webgal_dir.add_index_page(subgals, galleries)
-                    galleries = []
-                    how_many_medias = 0
-        except StopIteration:
-            if len(galleries) > 0:
+        for subgal in subgals_it:
+            how_many_medias += subgal.get_media_count()
+            galleries.append((subgal, subgal.medias))
+            if how_many_medias > self.webgal_dir.thumbs_per_page:
                 self.webgal_dir.add_index_page(subgals, galleries)
+                galleries = []
+                how_many_medias = 0
+
+        if len(galleries) > 0:
+            self.webgal_dir.add_index_page(subgals, galleries)
 
     def __fill_real_pagination(self):
         medias_amount = len(self.webgal_dir.medias)
@@ -371,7 +368,7 @@ class WebalbumDir(make.FileMakeObject):
             logging.info(_("  MKDIR %%WEBALBUMROOT%%/%s"),
                          self.source_dir.strip_root())
             logging.debug("(%s)", self.path)
-            os.makedirs(self.path, mode=0755)
+            os.makedirs(self.path, mode=0o755)
             self.stamp_delete() # Directory did not exist, mark it as so
 
         if self.config.getboolean('webgal', 'dirzip')\
@@ -404,7 +401,7 @@ class WebalbumDir(make.FileMakeObject):
     def __parse_browse_sizes(self, sizes_string):
         for single_def in sizes_string.split(','):
             name, string_size = single_def.split('=')
-            name = name.decode(locale.getpreferredencoding())
+            name = py2compat.u(name, locale.getpreferredencoding())
             if name == '':
                 raise ValueError(_("Sizes is a comma-separated list of size names and specs:\n\t e.g. \"small=640x480,medium=1024x768\"."))
             if name == genmedia.THUMB_SIZE_NAME:
@@ -421,7 +418,7 @@ class WebalbumDir(make.FileMakeObject):
             try:
                 self.newsizers[size_name] = newsize.get_newsizer(size_string)
             except newsize.NewsizeStringParseError:
-                raise ValueError(_("'%s' for size '%s' does not describe a known size syntax.") % (size_string.decode(locale.getpreferredencoding()), size_name, ))
+                raise ValueError(_("'%s' for size '%s' does not describe a known size syntax.") % (py2compat.u(size_string, locale.getpreferredencoding()), size_name, ))
 
     def __parse_sort(self, sort_string):
         try:
@@ -445,7 +442,7 @@ class WebalbumDir(make.FileMakeObject):
                     tpl_vars[option] = value
                 except ValueError:
                     value = self.config.get('template-vars', option)
-                    value = value.decode(locale.getpreferredencoding())
+                    value = py2compat.u(value, locale.getpreferredencoding())
                     tpl_vars[option] = genshi.core.Markup(value)
 
         return tpl_vars
@@ -453,8 +450,8 @@ class WebalbumDir(make.FileMakeObject):
     def __configure(self):
         config_dirs = self.source_dir.parent_paths()[:-1]  # strip root dir
         config_dirs.reverse()  # from root to deepest
-        config_files = map(lambda d: os.path.join(d, SOURCEDIR_CONFIGFILE),
-                           config_dirs)
+        config_files = list(map(lambda d: os.path.join(d, SOURCEDIR_CONFIGFILE),
+                                config_dirs))
         logging.debug(_("  Trying loading gallery configs: %s"),
                       ', '.join(map(self.source_dir.strip_root,
                                     config_files)))
@@ -494,7 +491,7 @@ class WebalbumDir(make.FileMakeObject):
         self.webalbumpic_bg = self.config.get('webgal', 'webalbumpic-bg')
         self.webalbumpic_type = self.config.get('webgal', 'webalbumpic-type')
         try:
-            self.webalbumpic_size = map(int, self.config.get('webgal', 'webalbumpic-size').split('x'))
+            self.webalbumpic_size = list(map(int, self.config.get('webgal', 'webalbumpic-size').split('x')))
             if len(self.webalbumpic_size) != 2:
                 raise ValueError
         except ValueError:
@@ -557,7 +554,7 @@ class WebalbumDir(make.FileMakeObject):
         if self.flatten_below():
             return 0
         else:
-            len(self.source_dir.subdirs)
+            return len(self.source_dir.subdirs)
 
     def get_all_subgals(self):
         all_subgals = list(self.subgals)  # We want a copy here.
@@ -647,9 +644,8 @@ class WebalbumDir(make.FileMakeObject):
         expected_dirs = map(lambda dn: os.path.join(self.path, dn), dirnames)
         for dest_file in os.listdir(self.path):
             dest_file = os.path.join(self.path, dest_file)
-            if not isinstance(dest_file, unicode):
-                # FIXME: No clue why this happens, but it happens!
-                dest_file = dest_file.decode(sys.getfilesystemencoding())
+            # FIXME: No clue why this happens, but it happens!
+            dest_file = py2compat.u(dest_file, sys.getfilesystemencoding())
             if dest_file not in self.output_items and\
                 dest_file not in expected_dirs and\
                     dest_file not in extra_files:
@@ -689,7 +685,7 @@ class SharedFiles(make.FileMakeObject):
         if not os.path.isdir(self.path):
             logging.info(_("MKDIR %SHAREDDIR%"))
             logging.debug("(%s)", self.path)
-            os.makedirs(self.path, mode=0755)
+            os.makedirs(self.path, mode=0o755)
 
         super(SharedFiles, self).__init__(self.path)
 
@@ -745,7 +741,7 @@ class AlbumGenProgress(object):
         self._task_percent = None
         self.updated()
 
-    def __unicode__(self):
+    def __str__(self):
         msg = _("Progress: dir %d/%d (%d%%), media %d/%d (%d%%)")\
               % (self._dirs_done, self._dirs_total,
                  100 * self._dirs_done // self._dirs_total,
@@ -767,6 +763,9 @@ class Album(object):
     def __init__(self, source_dir, config=None):
         self.source_dir = os.path.abspath(source_dir)
 
+        if not mediautils.HAVE_GST:
+            logging.warning(_('Video support is disabled: could not load GStreamer'))
+
         self.config = LazygalConfig()
 
         logging.info(_("Trying loading user config %s"), USER_CONFIG_PATH)
@@ -851,7 +850,7 @@ class Album(object):
         if dest_dir is None:
             dest_dir = self.config.getstr('global', 'output-directory')
         else:
-            dest_dir = dest_dir.decode(sys.getfilesystemencoding())
+            dest_dir = py2compat.u(dest_dir, sys.getfilesystemencoding())
         sane_dest_dir = os.path.abspath(os.path.expanduser(dest_dir))
 
         pub_url = self.config.getstr('global', 'puburl')
