@@ -23,10 +23,11 @@ import logging
 import codecs
 import datetime
 
-from lazygal.pygexiv2 import GExiv2
+from .pygexiv2 import GExiv2
 from PIL import Image as PILImage
 
-from lazygal import make
+from . import py2compat
+from . import make
 
 from fractions import Fraction
 
@@ -82,10 +83,11 @@ def decode_exif_user_comment(raw, imgpath):
     if cset == 'Unicode':
         encoding = None
         try:
-            text.decode('utf-8')
+            py2compat.u(text, 'utf-8')
         except UnicodeDecodeError:
-            im = PILImage.open(imgpath)
-            endianess = im.app['APP1'][6:8]
+            with open(imgpath, 'rb') as im_fp:
+                im = PILImage.open(im_fp)
+                endianess = im.app['APP1'][6:8]
             if endianess == 'MM':
                 encoding = 'utf-16be'
             elif endianess == 'II':
@@ -103,9 +105,9 @@ def decode_exif_user_comment(raw, imgpath):
 
     # Return the decoded string according to the found encoding.
     try:
-        return text.decode(encoding)
+        return py2compat.u(text, encoding)
     except UnicodeDecodeError:
-        return text.decode(encoding, 'replace')
+        return py2compat.u(text, encoding, 'replace')
 
 
 class FileMetadata(object):
@@ -113,25 +115,20 @@ class FileMetadata(object):
     def __init__(self, path):
         self.path = path
 
-    def contents(self, splitter=None):
+    def contents(self, splitter=None, firstline=False):
         try:
             with codecs.open(self.path, 'r', FILE_METADATA_ENCODING) as f:
-                # Not sure why codecs.open() does not skip the UTF-8 BOM. Maybe
-                # this is because the BOM is not required and utf-8-sig handles
-                # this in a better way. Anyway, the following code skips the
-                # UTF-8 BOM if it is present.
-                if FILE_METADATA_ENCODING == 'utf-8':
-                    maybe_bom = f.read(1).encode(FILE_METADATA_ENCODING)
-                    if maybe_bom != codecs.BOM_UTF8: f.seek(0)
-
-                c = f.read()
+                if firstline:
+                    c = f.readline()
+                else:
+                    c = f.read()
         except IOError:
             return None
 
-        if splitter is not None:
-            return map(lambda s: s.strip(), c.split(splitter))
-        else:
+        if splitter is None or (firstline and splitter == '\n'):
             return c.strip()
+        else:
+            return map(lambda s: s.strip(), c.split(splitter))
 
 
 class ImageInfoTags(object):
@@ -152,7 +149,7 @@ class ImageInfoTags(object):
                    ):
             try:
                 dt_str = self._metadata[tag]
-                dt = datetime.datetime.strptime(dt_str, GEXIV2_DATE_FORMAT)
+                dt = py2compat.datetime.strptime(dt_str, GEXIV2_DATE_FORMAT)
             except (KeyError, ValueError) as StrptimeError:
                 # ValueError: bypass errors such as "time data '0000:00:00
                 # 00:00:00' does not match format '%Y:%m:%d %H:%M:%S'"
@@ -246,16 +243,15 @@ class ImageInfoTags(object):
 
     def _fallback_to_encoding(self, encoded_string, encoding=FALLBACK_ENCODING):
         if encoded_string is None: raise ValueError
-        if type(encoded_string) is unicode: return encoded_string
+        if py2compat.isunicode(encoded_string): return encoded_string
         try:
             return encoded_string.decode(encoding)
         except UnicodeDecodeError:
             return encoded_string.decode(encoding, 'replace')
 
     def get_exif_usercomment(self):
-        ret = self._metadata['Exif.Photo.UserComment'].strip(' \0\x00')
-        if type(ret) is not unicode: # the EXIF lib did not do the work for us
-            ret = decode_exif_user_comment(ret, self.image_path)
+        ret = self._metadata['Exif.Photo.UserComment'].strip(' \0\x00\n')
+        ret = decode_exif_user_comment(ret, self.image_path)
         if ret == 'User comments':
             return ''
         return ret
@@ -446,7 +442,7 @@ class DirectoryMetadata(make.GroupTask):
         if path is None or not os.path.exists(path):
             raise NoMetadata(_('Could not open metadata file %s') % path)
 
-        f = file(path, 'r')
+        f = open(path, 'r')
         for line in f:
             for tag in MATEW_TAGS.keys():
                 tag_text = MATEW_TAGS[tag]
@@ -459,7 +455,7 @@ class DirectoryMetadata(make.GroupTask):
                         data = data[1:]
                     if data[-1] == '"':
                         data = data[:-1]
-                    data = data.decode(FILE_METADATA_ENCODING)
+                    data = py2compat.u(data, FILE_METADATA_ENCODING)
 
                     if tag == 'album_picture':
                         if subdir is not None:
@@ -489,9 +485,9 @@ class DirectoryMetadata(make.GroupTask):
                 metadata['album_description'] = fmd
 
         if 'album_picture' not in metadata.keys():
-            fmd = FileMetadata(os.path.join(subdir, 'album-picture')).contents(splitter='\n')
+            fmd = FileMetadata(os.path.join(subdir, 'album-picture')).contents(splitter='\n', firstline=True)
             if fmd is not None:
-                metadata['album_picture'] = os.path.join(subdir, fmd[0])
+                metadata['album_picture'] = os.path.join(subdir, fmd)
 
         return metadata
 
@@ -563,8 +559,7 @@ class DefaultMetadata(make.FileMakeObject):
 
         logging.info(_("GEN %s"), self._path)
 
-        f = file(self._path, 'w')
-        f.write(codecs.BOM_UTF8)
+        f = open(self._path, 'w')
         f.write('# Directory metadata for lazygal, Matew format\n')
         f.write('Album name "%s"\n'
                 % self.source_dir.human_name.encode('utf-8'))
