@@ -21,16 +21,17 @@ import logging
 import json
 import codecs
 import locale
+import time
 
 from genshi.core import START
 from genshi.template import TemplateLoader, MarkupTemplate, NewTextTemplate
 from genshi.template import TemplateNotFound
 from genshi.template.eval import UndefinedError
 from genshi.input import XMLParser
-import __init__
 
-import timeutils
-import pathutils
+import lazygal
+from . import py2compat
+from . import pathutils
 
 
 DEFAULT_THEME = 'default'
@@ -47,9 +48,15 @@ class LazygalTemplate(object):
         self.genshi_tpl = genshi_tpl
 
     def __complement_values(self, values):
-        values['gen_datetime'] = timeutils.Datetime()
-        values['gen_date'] = values['gen_datetime'].strftime('%c')
-        values['lazygal_version'] = __init__.__version__
+        values['gen_datetime'] = py2compat.datetime.now()
+
+        # using time.strftime() here instead of datetime.strftime() because
+        # the latter does not carry the current timezone info, and '%c' in some
+        # locales needs to display tzname.
+        values['gen_date'] = py2compat.u(time.strftime('%c'))
+
+        values['lazygal_version'] = lazygal.__version__
+
         return values
 
     def __generate(self, values):
@@ -69,22 +76,12 @@ class LazygalTemplate(object):
     def dump(self, values, dest):
         self.__complement_values(values)
 
-        page = open(dest, 'w')
+        page = open(dest, 'wb')
         try:
             self.__generate(values).render(method=self.serialization_method,
                                            out=page, encoding='utf-8')
-        except UnicodeDecodeError:
-            problematic_vars = []
-            for key, value in values.items():
-                if type(value) is not unicode:
-                    try:
-                        str(value).decode('utf-8')
-                    except UnicodeDecodeError:
-                        problematic_vars.append(key)
-            print 'Problematic template vars : %s' % ', '.join(problematic_vars)
-            raise
-        except UndefinedError, e:
-            print 'W: %s' % e
+        except UndefinedError as e:
+            print('W: %s' % e)
             raise
         finally:
             page.close()
