@@ -22,6 +22,7 @@ import tempfile
 import unittest
 import codecs
 
+from lazygal import py2compat
 from lazygal.sourcetree import Directory
 from lazygal.generators import Album
 
@@ -34,7 +35,7 @@ SAMPLE_IMG = os.path.join(SAMPLES_DIR, 'sample.jpg')
 import gettext
 LOCALES_PATH = os.path.normpath(os.path.join(os.path.dirname(__file__),
                                              'build', 'mo'))
-gettext.install('lazygal', LOCALES_PATH, unicode=1)
+gettext.install('lazygal', LOCALES_PATH)
 
 
 # Init quiet logging
@@ -51,33 +52,6 @@ def has_symlinks():
         return True
 
 
-class qnd_skipIf(object):
-    """
-    Quick and dirty unittest.skipIf decorator implementation to be able to run
-    the test suite using python < 2.7 .
-    """
-
-    def __init__(self, cond, reason):
-        self.cond = cond
-        self.reason = reason
-
-    def __call__(self, f):
-        def nf(*args, **kwargs):
-            if self.cond:
-                print 'skipped: %s' % self.reason
-                return
-            f(*args, **kwargs)
-        return nf
-
-
-try:
-    # Python >= 2.7
-    skip = unittest.skipIf
-except AttributeError:
-    # Python < 2.7
-    skip = qnd_skipIf
-
-
 class LazygalTest(unittest.TestCase):
 
     def setUp(self):
@@ -86,7 +60,7 @@ class LazygalTest(unittest.TestCase):
     def get_working_path(self):
         new_wd = tempfile.mkdtemp()
         self.__workdirs.append(new_wd)
-        return unicode(new_wd)
+        return py2compat.u(new_wd)
 
     def get_sample_path(self, sample):
         return os.path.join(SAMPLES_DIR, sample)
@@ -96,13 +70,9 @@ class LazygalTest(unittest.TestCase):
         shutil.copy(SAMPLE_IMG, img_path)
         return img_path
 
-    def create_file(self, path, contents='', bom=True):
-        f = open(path, 'w')
-        enc = 'utf-8'
-        if bom:
-            f.write(codecs.BOM_UTF8)
-        f.write(contents.encode(enc))
-        f.close()
+    def create_file(self, path, contents=''):
+        with codecs.open(path, 'w', 'utf-8') as f:
+            f.write(contents)
 
     def tearDown(self):
         for wd in self.__workdirs:
