@@ -23,7 +23,8 @@ import shutil
 
 from PIL import Image
 
-from __init__ import LazygalTestGen, skip, has_symlinks
+from lazygal import py2compat
+from . import LazygalTestGen, has_symlinks
 import lazygal.config
 from lazygal.generators import WebalbumDir
 from lazygal.sourcetree import Directory
@@ -94,7 +95,7 @@ class TestGenerators(LazygalTestGen):
                                   [], pics, self.album)
         dest_subgal = WebalbumDir(source_subgal, [], self.album, dest_path)
         expected = map(lambda fn:
-                       unicode(os.path.join(dest_path, 'subgal', fn)),
+                       py2compat.u(os.path.join(dest_path, 'subgal', fn)),
                        ['extra_thumb2.jpg',
                         'img6_thumb.jpg',
                         'img6_small.jpg', 'img6_medium.jpg',
@@ -106,7 +107,7 @@ class TestGenerators(LazygalTestGen):
         source_gal = Directory(self.source_dir, [source_subgal], [], self.album)
         dest_gal = WebalbumDir(source_gal, [dest_subgal], self.album, dest_path)
         expected =  map(lambda fn:
-                        unicode(os.path.join(dest_path, fn)),
+                        py2compat.u(os.path.join(dest_path, fn)),
                         ['extra_thumb.jpg', 'extra_dir']
                        )
         self.assertEqual(sorted(dest_gal.list_foreign_files()),
@@ -150,9 +151,9 @@ class TestGenerators(LazygalTestGen):
             for f in ['extra_dir']:
                 self.assertFalse(os.path.isdir(os.path.join(dest_path, f)))
         except AssertionError:
-            print "\n contents of dest_path : "
-            print sorted(os.listdir(dest_path))
-            print sorted(os.listdir(os.path.join(dest_path, 'subgal')))
+            print("\n contents of dest_path : ")
+            print(sorted(os.listdir(dest_path)))
+            print(sorted(os.listdir(os.path.join(dest_path, 'subgal'))))
             raise
 
     def test_clean_empty_dirs(self):
@@ -185,9 +186,9 @@ class TestGenerators(LazygalTestGen):
             for f in ['subgal']:
                 self.assertTrue(os.path.isdir(os.path.join(dest_path, f)))
         except AssertionError:
-            print "\n contents of dest_path after first generation: "
-            print sorted(os.listdir(dest_path))
-            print sorted(os.listdir(os.path.join(dest_path, 'subgal')))
+            print("\n contents of dest_path after first generation: ")
+            print(sorted(os.listdir(dest_path)))
+            print(sorted(os.listdir(os.path.join(dest_path, 'subgal'))))
             raise
 
         # remove the pic in subgal, and force a new generation
@@ -205,13 +206,13 @@ class TestGenerators(LazygalTestGen):
             for f in ['subgal']:
                 self.assertFalse(os.path.isdir(os.path.join(dest_path, f)))
         except AssertionError:
-            print "\n contents of dest_path after the second generation: "
-            print sorted(os.listdir(dest_path))
-            print sorted(os.listdir(os.path.join(dest_path, 'subgal')))
+            print("\n contents of dest_path after the second generation: ")
+            print(sorted(os.listdir(dest_path)))
+            print(sorted(os.listdir(os.path.join(dest_path, 'subgal'))))
             raise
 
 
-    @skip(not has_symlinks(), 'symlinks not supported on platform')
+    @unittest.skipIf(not has_symlinks(), 'symlinks not supported on platform')
     def test_originals_symlinks(self):
         config = lazygal.config.LazygalConfig()
         config.set('webgal', 'original', 'Yes')
@@ -384,8 +385,8 @@ class TestGenerators(LazygalTestGen):
             self.assertFalse(os.path.isfile(os.path.join(dest_dir, 'sdir_untagged', 'untagged.jpg')))
             self.assertFalse(os.path.isdir(os.path.join(dest_dir, 'sdir_untagged')))
         except AssertionError:
-            print "\n contents of dest_dir : "
-            print os.listdir(dest_dir)
+            print("\n contents of dest_dir : ")
+            print(os.listdir(dest_dir))
             raise
 
     def test_filter_and_dirzip(self):
@@ -421,8 +422,8 @@ class TestGenerators(LazygalTestGen):
             self.assertTrue(os.path.isfile(os.path.join(dest_dir, 'tagfound2_thumb.jpg')))
             self.assertFalse(os.path.isfile(os.path.join(dest_dir, 'false_thumb.jpg')))
         except AssertionError:
-            print "\n contents of dest_dir : "
-            print os.listdir(dest_dir)
+            print("\n contents of dest_dir : ")
+            print(os.listdir(dest_dir))
             raise
 
 class TestSpecialGens(LazygalTestGen):
@@ -469,7 +470,7 @@ class TestSpecialGens(LazygalTestGen):
         # FIXME: Check dest dir contents, test only catches uncaught exceptions
         # for now...
 
-    @skip(not has_symlinks(), 'symlinks not supported on platform')
+    @unittest.skipIf(not has_symlinks(), 'symlinks not supported on platform')
     def test_dir_symlink(self):
         """
         The generator should follow symlinks on directories, but should not get
