@@ -20,8 +20,12 @@
 import unittest
 import os
 import locale
-from __init__ import LazygalTest
+import datetime
+
+
+from . import LazygalTest
 from lazygal import metadata
+from lazygal import py2compat
 metadata.FILE_METADATA_ENCODING = 'utf-8'  # force for these tests
 from lazygal.generators import Album
 from lazygal.sourcetree import Directory
@@ -122,6 +126,34 @@ class TestFileMetadata(LazygalTest):
 
         self.assertEqual(im_md.get_comment(), u'unicode test : éàê')
 
+    def test_usercomment_empty_and_encoding(self):
+        """
+        Exif.Photo.UserComment: charset="Ascii"
+
+        Exif.Image.ImageDescription: unset
+        Iptc.Application2.ObjectName: Jasper the Bear
+
+        In this example, the IPTC tag should be chosen because the
+        EXIF photo user comment should be considered empty.
+        """
+        sample = 'sample-usercomment-empty-and-encoding.jpg'
+        im_md = metadata.ImageInfoTags(self.get_sample_path(sample))
+
+        self.assertEqual(im_md.get_comment(), u'Jasper the Bear')
+
+    def test_exif_date(self):
+        sample = 'sample.jpg'
+        im_md = metadata.ImageInfoTags(self.get_sample_path(sample))
+        d = im_md.get_date()
+        self.assertEqual(d, datetime.datetime(2010, 2, 5, 23, 56, 24))
+        self.assertEqual(d.timestamp(), 1265410584.0)
+
+        sample = 'sample-model-nikon1.jpg'
+        im_md = metadata.ImageInfoTags(self.get_sample_path(sample))
+        d = im_md.get_date()
+        self.assertEqual(d, datetime.datetime(2011, 5, 21, 22, 19, 30))
+        self.assertEqual(d.timestamp(), 1306009170.0)
+
     def test_model(self):
         sample = 'sample-model-nikon1.jpg'
         im_md = metadata.ImageInfoTags(self.get_sample_path(sample))
