@@ -18,7 +18,9 @@
 
 import unittest
 import os
-from __init__ import LazygalTest
+
+from . import LazygalTest
+from lazygal import py2compat
 from lazygal.generators import Album
 from lazygal.sourcetree import Directory
 
@@ -58,7 +60,7 @@ class TestSourceTree(LazygalTest):
             os.path.join(self.source_dir, 'joe'),
             self.source_dir,
         ]
-        self.assertEqual(d.parent_paths(), map(unicode, expected))
+        self.assertEqual(d.parent_paths(), list(map(py2compat.u, expected)))
 
 
 if __name__ == '__main__':
